@@ -15,6 +15,7 @@ class Tabix {
 
     htsFile* fn;
     tbx_t* tbx;
+    kstring_t str;
     hts_itr_t* iter;
     const tbx_conf_t *idxconf;
     int tid, beg, end;
@@ -23,7 +24,6 @@ class Tabix {
     vector<string>::iterator current_chrom;
 
 public:
-
     string filename;
     vector<string> chroms;
 
@@ -31,8 +31,10 @@ public:
     Tabix(string& file);
     ~Tabix(void);
 
+    const kstring_t * getKstringPtr();
     void getHeader(string& header);
     bool setRegion(string& region);
     bool getNextLine(string& line);
+    bool getNextLineKS();
 
 };
